---
sidebar_label: frequent_itemsets_compare
title: modules.itemsets.frequent_itemsets_compare
---

## FrequentItemsetsCompare Objects

```python
class FrequentItemsetsCompare(Experiment)
```

Compares two sets of frequent itemsets dividing the first from the second
used as reference.
The resulting set of frequent itemsets is the union of both sets.

